==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/_internal/implicit/overridable/contact_ratio_requirements.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears import _332
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Type, Any, TypeVar

    Self = TypeVar("Self", bound="Overridable_ContactRatioRequirements")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_ContactRatioRequirements",)


class Overridable_ContactRatioRequirements(mixins.OverridableMixin, Enum):
    """Overridable_ContactRatioRequirements

    A specific implementation of 'Overridable' for 'ContactRatioRequirements' types.
    """

    __qualname__ = "ContactRatioRequirements"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_ContactRatioRequirements]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(
        cls: "Type[Overridable_ContactRatioRequirements]",
    ) -> "_332.ContactRatioRequirements":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _332.ContactRatioRequirements
        """
        return _332.ContactRatioRequirements

    @classmethod
    def implicit_type(cls: "Type[Overridable_ContactRatioRequirements]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _332.ContactRatioRequirements.type_()

    @property
    def value(self: "Self") -> "_332.ContactRatioRequirements":
        """mastapy._private.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_332.ContactRatioRequirements":
        """mastapy._private.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_332.ContactRatioRequirements":
        """mastapy._private.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/overridable/contact_ratio_requirements.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears import _340

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_ContactRatioRequirements")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_ContactRatioRequirements",)


class Overridable_ContactRatioRequirements(mixins.OverridableMixin, Enum):
    """Overridable_ContactRatioRequirements

    A specific implementation of 'Overridable' for 'ContactRatioRequirements' types.
    """

    __qualname__ = "ContactRatioRequirements"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_ContactRatioRequirements]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(
        cls: "Type[Overridable_ContactRatioRequirements]",
    ) -> "_340.ContactRatioRequirements":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _340.ContactRatioRequirements
        """
        return _340.ContactRatioRequirements

    @classmethod
    def implicit_type(cls: "Type[Overridable_ContactRatioRequirements]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _340.ContactRatioRequirements.type_()

    @property
    def value(self: "Self") -> "_340.ContactRatioRequirements":
        """mastapy.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_340.ContactRatioRequirements":
        """mastapy.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_340.ContactRatioRequirements":
        """mastapy.gears.ContactRatioRequirements

        Note:
            This property is readonly.
        """
        return None
